<?php
namespace WPC\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class RamadanTimes extends Widget_Base{

  public function get_name(){
    return 'ramadan_times';
  }

  public function get_title(){
    return 'Ramadan Times';
  }

  public function get_icon(){
    return 'fa fa-clock';
  }

  public function get_categories(){
    return ['nauthemes'];
  }

  protected function _register_controls(){
	 

    $this->start_controls_section(
      'section_content',
      [
        'label' => 'Settings',
      ]
    );

    $this->add_control(
      'title',
      [
        'label' => 'Block Title',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'FASTING TIMES IN YOUR CITY'
      ]
    );
	
	$this->add_control(
		'date_display',
		[
			'label' => __( 'Display Date', 'tabligh' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'default' => 'yes',
			'options' => [
				'yes'  => __( 'Yes', 'tabligh' ),
				'no' => __( 'No', 'tabligh' ),
			],
		]
	);
	
	$this->add_control(
      'sehr',
      [
        'label' => 'Sehr Title',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Sehr Time Today:'
      ]
    );
	
	$this->add_control(
      'sehr_dua',
      [
        'label' => 'Sehr Dua',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'وَبِصَوْمِ غَدٍ نَّوَيْتُ مِنْ شَهْرِ رَمَضَانَ'
      ]
    );
	
	$this->add_control(
      'sehr_dua_trans',
      [
        'label' => 'Sehr Dua Translation',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'I intend to keep the fast for tomorrow in the month of Ramadan'
      ]
    );
	
		
	$this->add_control(
      'iftar',
      [
        'label' => 'Iftar Title',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Iftar Time Today:'
      ]
    );
	
	$this->add_control(
      'iftar_dua',
      [
        'label' => 'Iftar Dua',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'اللّٰهُمَّ اِنِّى لَكَ صُمْتُ وَبِكَ اٰمَنْتُ وَعَليْكَ تَوَكَّلتُ وَ عَلٰى رِزْقِكَ اَفْطَرْتُ'
      ]
    );
	
	$this->add_control(
      'iftar_dua_trans',
      [
        'label' => 'Iftar Dua Translation',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'O Allah! I fasted for You and I believe in You and I put my trust in You and I break my fast with Your sustenance'
      ]
    );

	$this->add_control(
      'link_1_text',
      [
        'label' => 'Link 1 (Text)',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Ramadan Calendar 2020'
      ]
    );
	
	$this->add_control(
      'link_1_url',
      [
        'label' => 'Link 1 Address',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => '#'
      ]
    );
	
	$this->add_control(
      'link_2_text',
      [
        'label' => 'Link 2 (Text)',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Prayer Times'
      ]
    );
	
	$this->add_control(
      'link_2_url',
      [
        'label' => 'Link 2 Address',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => '#'
      ]
    );
	
	$this->add_control(
			'dark_color',
			[
				'label' => __( 'Dark Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .thm-layer:before' => 'background-color: {{VALUE}}',
				],
				'default' => '#0a993c',
			]
		);
		
		$this->add_control(
			'light_color',
			[
				'label' => __( 'Light Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .thm-layer:after' => 'background-color: {{VALUE}}',
				],
				'default' => '#147736',
			]
		);
		
	
    $this->end_controls_section();
  }
  

	protected function render(){
	  
		$settings = $this->get_settings_for_display(); 
		
		/* Sehr Iftar Timings from salat plugin file */
		$sehr_iftar = tabligh_ramadan_timings_shortcode();
	
	
	?>
	
		<style>
			.seif-block .thm-layer:before {background-color:<?php echo $settings['light_color']; ?>}
			.seif-block .thm-layer:after{background-color:<?php echo $settings['dark_color']; ?>}
			.ramadan-times-additional .thm-btn.btn1{ background:<?php echo $settings['dark_color']; ?> }
			.ramadan-times-additional .thm-btn.btn2{ background:<?php echo $settings['light_color']; ?> }
			.thm-btn.btn1:hover span{background:<?php echo $settings['dark_color']; ?>}
			.thm-btn.btn2:hover span{background:<?php echo $settings['light_color']; ?>}
			.ramadan-times {
			background: linear-gradient(
				106deg
				, <?php echo $settings['light_color']; ?>, <?php echo $settings['light_color']; ?> 26%, <?php echo $settings['dark_color']; ?>), linear-gradient(
				106deg
				, rgba(71, 229, 238, 0), <?php echo $settings['dark_color']; ?> 28%, <?php echo $settings['dark_color']; ?> 74%);
					width: 100%;
					padding: 75px 0px 50px 0px;
			}
		</style>
		
		<section class = "seif-block">
			<div class="w-100 black-layer opc1 position-relative">
			<div class="fixed-bg" style="background-image: url(<?php echo get_template_directory_uri().'/assets/images/sec-bg3.jpg'; ?>);"></div>
				<div id="ramadan-times" class="ramadan-times section-container clearfix">
				<?php if($settings['title']){ ?>
					<div class="ramadan-times-title">
						<h2 class="uppercase"><?php echo $settings['title'];?></h2>
						<?php if($settings['date_display'] == 'yes' && isset($sehr_iftar[2])){ ?> <p><?php echo $sehr_iftar[2]; ?> <?php echo '(' . $sehr_iftar[3] . ')'; ?> </p><?php } ?>
					</div>
				<?php } ?>
					<div class="ramadan-iftar-seher container">
						<div class="iftar-seher-block">
							<div class="row iftar-seher-content">
								<div class="col-md-6 col-sm-12 col-lg-6">
									<div class="iftar-seher-time">
										<?php if($settings['sehr']){ ?><span><?php echo $settings['sehr']; ?></span><?php } ?>
										<?php if(isset($sehr_iftar[0])) { ?>
										<div class = "time-sec">
											<img src= "<?php echo esc_url(get_template_directory_uri().'/assets/images/sunrise-icon.png');?>" alt = "<?php esc_attr__('Sunrise Icon','tabligh');?>"/>
											<p><?php echo $sehr_iftar[0]; ?></p>
										</div>
										<?php } ?>
									</div>
									<?php if($settings['sehr_dua']){ ?>
										<div class="seher-arabic">
											<span class=""><?php echo $settings['sehr_dua']; ?></span>
										</div>
									<?php } ?>
									<?php if($settings['sehr_dua_trans']){ ?>
										<div class="seher-trans">
											<span><?php echo $settings['sehr_dua_trans']; ?></span>
										</div>
									<?php } ?>
								</div>
								<div class="col-md-6 col-sm-12 col-lg-6">
									<div class="iftar-seher-time">
										<?php if($settings['iftar']){ ?><span><?php echo $settings['iftar']; ?></span><?php } ?>
										<?php if(isset($sehr_iftar[1])) { ?>
											<div class = "time-sec">
												<img src= "<?php echo esc_url(get_template_directory_uri().'/assets/images/sunset-icon.png');?>" alt = "<?php esc_attr__('Sunset Icon','tabligh');?>"/>
												<p><?php echo $sehr_iftar[1]; ?></p>
											</div>
										<?php } ?>
									</div>
									<?php if($settings['iftar_dua']){ ?>
										<div class="iftar-arabic">
										   <span><?php echo $settings['iftar_dua']; ?></span>
										</div>
									<?php } ?>
									<?php if($settings['iftar_dua_trans']){ ?>
										<div class="iftar-trans">
											<span><?php echo $settings['iftar_dua_trans']; ?></span>
										</div>
									<?php }?>
								</div>
							</div>
						</div>
					</div>
					<?php if($settings['link_1_text'] || $settings['link_2_text']){ ?>
						<div class="ramadan-times-additional">
							<?php if($settings['link_1_text']){ ?>
								<a href="<?php echo $settings['link_1_url']; ?>" target="_blank" class="thm-btn btn1"><?php echo $settings['link_1_text']; ?><span></span><span></span><span></span><span></span></a>
							<?php } ?>
							<?php if($settings['link_2_text']){ ?>
								<a href="<?php echo $settings['link_2_url']; ?>" target="_blank" class="thm-btn btn2"><span></span><span></span><span></span><span></span><?php echo $settings['link_2_text']; ?></a>
							<?php } ?>
						</div>
					<?php } ?>
				</div>
			</div>
		</section>
    <?php
  }
}
